==> owncloud-10.2.0.zip: owncloud/apps/systemtags/l10n/ru.js <==
OC.L10N.register(
    "systemtags",
    {
    "Tags" : "Метки",
    "Tagged files" : "Файлы с метками",
    "Select tags to filter by" : "Выберите метки для фильтра",
    "Please select tags to filter by" : "Выберите метки для фильтра",
    "No files found for the selected tags" : "Для выбранных меток файлов не найдено",
    "<strong>System tags</strong> for a file have been modified" : "<strong>Системные метки</strong> файла были изменены",
    "You assigned system tag %3$s" : "Вы назначили системную метку %3$s",
    "%1$s assigned system tag %3$s" : "%1$s назначил системную метку %3$s",
    "You unassigned system tag %3$s" : "Вы убрали системную метку %3$s",
    "%1$s unassigned system tag %3$s" : "%1$s убрал системную метку %3$s",
    "You created system tag %2$s" : "Вы создали системную метку %2$s",
    "%1$s created system tag %2$s" : "%1$s создал системную метку %2$s",
    "You deleted system tag %2$s" : "Вы удалили системную метку %2$s",
    "%1$s deleted system tag %2$s" : "%1$s удалил системную метку %2$s",
    "You updated system tag %3$s to %2$s" : "Вы обновили системную метку %3$s на %2$s",
    "%1$s updated system tag %3$s to %2$s" : "%1$s обновил системную метку %3$s для %2$s",
    "You assigned system tag %3$s to %2$s" : "Вы назначили системную метку %3$s на %2$s",
    "%1$s assigned system tag %3$s to %2$s" : "%1$s назначил системную метку %3$s для %2$s",
    "You unassigned system tag %3$s from %2$s" : "Вы назначили системную метку %3$s из %2$s",
    "%1$s unassigned system tag %3$s from %2$s" : "%1$s убрал системную метку %3$s с %2$s",
    "%s (restricted)" : "%s (ограничено)",
    "%s (invisible)" : "%s (невидимые)",
    "No files in here" : "Здесь нет файлов",
    "No entries found in this folder" : "Нет элементов в этом каталоге",
    "Name" : "Имя",
    "Size" : "Размер",
    "Modified" : "Изменён",
    "%s (static)" : "%s (статические)"
},
"nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");

==> owncloud-10.4.1.zip: owncloud/apps/systemtags/l10n/ru.js <==
OC.L10N.register(
    "systemtags",
    {
    "Tags" : "Метки",
    "Tagged files" : "Файлы с метками",
    "Select tags to filter by" : "Выберите метки для фильтра",
    "Please select tags to filter by" : "Выберите метки для фильтра",
    "No files found for the selected tags" : "Для выбранных меток файлов не найдено",
    "<strong>System tags</strong> for a file have been modified" : "<strong>Системные метки</strong> файла были изменены",
    "You assigned system tag %3$s" : "Вы назначили системную метку %3$s",
    "%1$s assigned system tag %3$s" : "%1$s назначил системную метку %3$s",
    "You unassigned system tag %3$s" : "Вы убрали системную метку %3$s",
    "%1$s unassigned system tag %3$s" : "%1$s убрал системную метку %3$s",
    "You created system tag %2$s" : "Вы создали системную метку %2$s",
    "%1$s created system tag %2$s" : "%1$s создал системную метку %2$s",
    "You deleted system tag %2$s" : "Вы удалили системную метку %2$s",
    "%1$s deleted system tag %2$s" : "%1$s удалил системную метку %2$s",
    "You updated system tag %3$s to %2$s" : "Вы обновили системную метку %3$s на %2$s",
    "%1$s updated system tag %3$s to %2$s" : "%1$s обновил системную метку %3$s для %2$s",
    "You assigned system tag %3$s to %2$s" : "Вы назначили системную метку %3$s на %2$s",
    "%1$s assigned system tag %3$s to %2$s" : "%1$s назначил системную метку %3$s для %2$s",
    "You unassigned system tag %3$s from %2$s" : "Вы назначили системную метку %3$s из %2$s",
    "%1$s unassigned system tag %3$s from %2$s" : "%1$s убрал системную метку %3$s с %2$s",
    "%s (restricted)" : "%s (ограничено)",
    "%s (invisible)" : "%s (невидимые)",
    "%s (static)" : "%s (статические)",
    "No files in here" : "Здесь нет файлов",
    "No entries found in this folder" : "Нет элементов в этом каталоге",
    "Name" : "Имя",
    "Size" : "Размер",
    "Modified" : "Изменён"
},
"nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
